@@ -14,6 +14,7 @@ import random
 from diem.__VERSION__ import VERSION
 from concurrent.futures import Future, ThreadPoolExecutor, as_completed
 from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PublicKey
+from logging import Logger, getLogger
 
 from .. import diem_types, utils
 from . import jsonrpc_pb2 as rpc
@@ -188,6 +189,7 @@ class Client:
         timeout: typing.Optional[typing.Tuple[float, float]] = None,
         retry: typing.Optional[Retry] = None,
         rs: typing.Optional[RequestStrategy] = None,
+        logger: typing.Optional[Logger] = None,
     ) -> None:
         self._url: str = server_url
         self._session: requests.Session = session or requests.Session()
@@ -197,6 +199,7 @@ class Client:
         self._lock = threading.Lock()
         self._retry: Retry = retry or Retry(DEFAULT_MAX_RETRIES, DEFAULT_RETRY_DELAY, StaleResponseError)
         self._rs: RequestStrategy = rs or RequestStrategy()
+        self._logger: Logger = logger or getLogger(__name__)
 
     # high level functions
 
@@ -417,12 +420,36 @@ class Client:
         """submit signed transaction
 
         See [JSON-RPC API Doc](https://github.com/diem/diem/blob/master/json-rpc/docs/method_submit.md)
+
+        This method ignores StaleResponseError and does not retry on any submit errors, because re-submit any transaction
+        may get JsonRpcError `SEQUENCE_NUMBER_TOO_OLD` in multi-threads environment, for example:
+
+        1. thread-1: submit transaction.
+        2. server: receive submit transaction. The latest ledger version is X.
+        3. server: receive a new state sync. The latest ledger version becomes X+1.
+        4. thread-2: get_events (can be any get API).
+        5. server: receive get_events. The latest ledger version is X+1.
+        6. server: respond to get_events with latest ledger version == X+1.
+        7. thread-2: receive get_events response.
+        8. thread-2: update latest known ledger version X+1.
+        9. server: respond to submit transaction with latest ledger version == X.
+        10. thread-1: receive submit transaction response. Found response ledger version X < known version X+1.
+        11. thread-1: triggers StaleResponseError.
+        12. if we retry on StaleResponseError, the submitted transaction may end with JsonRpcError `SEQUENCE_NUMBER_TOO_OLD`
+            if the following events happened.
+        13. server: execute transaction, and the transaction sender account sequence number +1.
+        14. thread-1: submit the transaction again.
+        15. server: validate transaction sender account sequence number, and response SEQUENCE_NUMBER_TOO_OLD error.
+            However, the transaction was executed successfully, thus raising SEQUENCE_NUMBER_TOO_OLD error may cause
+            a re-submit with new account sequence number if client handled it improperly (without checking whether
+            the transaction is executed).
+
         """
 
         if isinstance(txn, diem_types.SignedTransaction):
             return self.submit(txn.bcs_serialize().hex())
 
-        self.execute("submit", [txn], result_parser=None)
+        self.execute_without_retry("submit", [txn], result_parser=None, ignore_stale_response=True)
 
     def wait_for_transaction(
         self, txn: typing.Union[diem_types.SignedTransaction, str], timeout_secs: typing.Optional[float] = None
@@ -567,7 +594,9 @@ class Client:
         request: typing.Dict[str, typing.Any],
         ignore_stale_response: bool,
     ) -> typing.Dict[str, typing.Any]:
+        self._logger.debug("http request body: %s", request)
         response = self._session.post(url, json=request, timeout=self._timeout)
+        self._logger.debug("http response body: %s", response.text)
         response.raise_for_status()
         try:
             json = response.json()
