@@ -13,7 +13,7 @@ from ..serde_types import uint64
 from ..auth_key import AuthKey
 from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PrivateKey, Ed25519PublicKey
 from typing import Dict, Optional, Tuple, Union
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, replace
 from copy import copy
 import time, json
 
@@ -119,15 +119,9 @@ class LocalAccount:
         """submit transaction with the given script
 
         This function creates transaction with current account sequence number (by json-rpc `get_account`
-        method), and retries on JsonRpcError in case there is another process is submitting transaction
-        at same time, which may cause SEQUENCE_NUMBER_TOO_OLD JsonRpcError.
+        method).
         """
-        retry = jsonrpc.Retry(10, 0.1, jsonrpc.JsonRpcError)
-        return retry.execute(lambda: self._submit_txn_without_retry(client, script))
 
-    def _submit_txn_without_retry(
-        self, client: jsonrpc.Client, script: diem_types.Script
-    ) -> diem_types.SignedTransaction:
         txn = self.create_txn(client, script)
         client.submit(txn)
         return txn
@@ -146,6 +140,25 @@ class LocalAccount:
             stdlib.encode_rotate_dual_attestation_info_script(new_url=base_url.encode("utf-8"), new_key=compliance_key),
         )
 
+    def gen_child_vasp(self, client: jsonrpc.Client, initial_balance: int, currency: str) -> "LocalAccount":
+        """Generates a new ChildVASP account if `self` is a ParentVASP account.
+
+        Raisees error with transaction execution failure if `self` is not a ParentVASP account.
+        """
+
+        child_vasp = replace(self, private_key=Ed25519PrivateKey.generate())
+        self.submit_and_wait_for_txn(
+            client,
+            stdlib.encode_create_child_vasp_account_script(
+                coin_type=utils.currency_code(currency),
+                child_address=child_vasp.account_address,
+                auth_key_prefix=child_vasp.auth_key.prefix(),
+                add_all_currencies=False,
+                child_initial_balance=initial_balance,
+            ),
+        )
+        return child_vasp
+
     def to_dict(self) -> Dict[str, str]:
         """export to a string only dictionary for saving and importing as config
 
