@@ -4,7 +4,7 @@
 from dataclasses import dataclass, field, asdict, fields
 from enum import Enum
 from typing import Optional, List, Dict, Any
-from .... import identifier, offchain, diem_types
+from .... import offchain, diem_types
 import json
 
 
@@ -22,29 +22,12 @@ class Account(Base):
         return self.kyc_data if self.kyc_data else offchain.individual_kyc_data()  # pyre-ignore
 
 
-@dataclass
-class PaymentUri(Base):
-    account_id: str
-    payment_uri: str
-
-    def intent(self, hrp: str) -> identifier.Intent:
-        return identifier.decode_intent(self.payment_uri, hrp)
-
-
 @dataclass
 class Subaddress(Base):
     account_id: str
     subaddress_hex: str
 
 
-@dataclass
-class Payment(Base):
-    account_id: str
-    currency: str
-    amount: int
-    payee: str
-
-
 @dataclass
 class Event(Base):
     account_id: str
@@ -96,10 +79,16 @@ class Transaction(Base):
         canceled = "canceled"
         pending = "pending"
 
+    class Type(str, Enum):
+        sent_payment = "sent_payment"
+        received_payment = "received_payment"
+        deposit = "deposit"
+
     account_id: str
     currency: str
     amount: int
     status: Status
+    type: Type
     cancel_reason: Optional[str] = field(default=None)
     payee: Optional[str] = field(default=None)
     subaddress_hex: Optional[str] = field(default=None)
